builtin_assume energy values are within bounds This helps optimize codegen for fsanitize=array-bounds. A relatively unscientific run of `perf record -g -- ./vpxenc -o /dev/null --ivf --codec=vp9 niklas_1280_720_30.y4m` show a reduction of ~25 % for samples in __ubsan_check_array_bounds in vp9_optimize_b after this change. This is a much bigger change than any other function. Bug: 478049916 Change-Id: I8bf7f4cd781093e5678789b21954d22641663a95